@@ -10,11 +10,11 @@ Acme::IAMB - The great new Acme::IAMB!
 
 =head1 VERSION
 
-Version 0.02
+Version 0.01
 
 =cut
 
-our $VERSION = '0.02_01';
+our $VERSION = '0.01';
 
 
 =head1 SYNOPSIS
@@ -48,7 +48,6 @@ sub function1 {
 
 sub function2 {
 }
-foobar
 
 =head1 AUTHOR
 
